summaryrefslogtreecommitdiffstats
path: root/webkit
diff options
context:
space:
mode:
authordarin@chromium.org <darin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-11-13 19:49:47 +0000
committerdarin@chromium.org <darin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-11-13 19:49:47 +0000
commitf8d1a1f86c3d5fec1a7943eb417b971b09fb1900 (patch)
treedc8fc267a03bef1e3436bb672cab21b1f8223448 /webkit
parent84140f23d6732ba99dd147bc71ae0a044549c50c (diff)
downloadchromium_src-f8d1a1f86c3d5fec1a7943eb417b971b09fb1900.zip
chromium_src-f8d1a1f86c3d5fec1a7943eb417b971b09fb1900.tar.gz
chromium_src-f8d1a1f86c3d5fec1a7943eb417b971b09fb1900.tar.bz2
Fix LayoutTests/http/tests/loading/gmail-assert-on-load.html test.
The trick here is to properly check for a Frame that has been removed by checking for a null Page. This matches what happens in other WebKit ports. R=dglazkov Review URL: http://codereview.chromium.org/10882 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@5359 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit')
-rw-r--r--webkit/glue/webframeloaderclient_impl.cc7
-rw-r--r--webkit/tools/layout_tests/test_lists/win/tests_fixable.txt1
2 files changed, 3 insertions, 5 deletions
diff --git a/webkit/tools/layout_tests/test_lists/win/tests_fixable.txt b/webkit/tools/layout_tests/test_lists/win/tests_fixable.txt
index 964f2ea..e3ffc73 100644
--- a/webkit/tools/layout_tests/test_lists/win/tests_fixable.txt
+++ b/webkit/tools/layout_tests/test_lists/win/tests_fixable.txt
@@ -1185,7 +1185,6 @@ V8 # LayoutTests/svg/carto.net/combobox.svg = FAIL
V8 # LayoutTests/fast/dom/Window/get-set-properties.html = PASS | FAIL
V8 # LayoutTests/fast/dom/Window/new-window-opener.html = PASS | FAIL
V8 # LayoutTests/fast/forms/access-key.html = PASS | FAIL
-V8 # LayoutTests/http/tests/loading/gmail-assert-on-load.html = PASS | FAIL
V8 # LayoutTests/http/tests/security/originHeader/origin-header-for-empty.html = FAIL | PASS
V8 # pending/security/block-test.html = FAIL
diff --git a/webkit/glue/webframeloaderclient_impl.cc b/webkit/glue/webframeloaderclient_impl.cc
index 946e784..7d7bcb2 100644
--- a/webkit/glue/webframeloaderclient_impl.cc
+++ b/webkit/glue/webframeloaderclient_impl.cc
@@ -396,14 +396,13 @@ bool WebFrameLoaderClient::dispatchDidLoadResourceFromMemoryCache(
}
void WebFrameLoaderClient::dispatchDidHandleOnloadEvents() {
- WebViewImpl* webview = webframe_->webview_impl();
// During the onload event of a subframe, the subframe can be removed. In
// that case, we have no webview. This is covered by
// LayoutTests/fast/dom/replaceChild.html
- if (!webview)
+ if (!webframe_->frame()->page())
return;
+ WebViewImpl* webview = webframe_->webview_impl();
WebViewDelegate* d = webview->delegate();
-
if (d)
d->DidHandleOnloadEventsForFrame(webview, webframe_);
}
@@ -396,14 +396,13 @@ bool WebFrameLoaderClient::dispatchDidLoadResourceFromMemoryCache(
// During the onload event of a subframe, the subframe can be removed. In
- // that case, we have no webview. This is covered by
+ // that case, it has no page. This is covered by
// LayoutTests/fast/dom/replaceChild.html